"""
AlgoInfinite - A collection of algorithms and data structures in Python.
"""

from .main import hello
from .data_structures import *
from .algorithms import *

__version__ = "0.2.0"
__author__ = "Madan Mohan Behera"