"""
Data structures collection for AlgoInfinite.
"""

from .linked_list import LinkedList
from .stack import Stack
# Import additional data structures as they're created

__all__ = ['LinkedList', 'Stack']